@@ -12,11 +12,11 @@ package MooX::Options;
 
 use strict;
 use warnings;
-our $VERSION = '4.015';    # VERSION
+our $VERSION = '4.016';    # VERSION
 use Carp;
 
 my @OPTIONS_ATTRIBUTES
-    = qw/format short repeatable negativable autosplit autorange doc long_doc order json/;
+    = qw/format short repeatable negativable autosplit autorange doc long_doc order json hidden/;
 
 sub import {
     my ( undef, @import ) = @_;
@@ -200,7 +200,7 @@ MooX::Options - Explicit Options eXtension for Object Class
 
 =head1 VERSION
 
-version 4.015
+version 4.016
 
 =head1 DESCRIPTION
 
@@ -507,6 +507,16 @@ By default all options have an order set to C<0>, and options are sorted by thei
 
   option 'at_the_end' => (is => 'ro', order => 999);
 
+=head2 hidden
+
+Hide option from doc but still an option you can use on command line.
+
+  option 'debug' => (is => 'ro', doc => 'hidden');
+
+Or
+
+  option 'debug' => (is => 'ro', hidden => 1);
+
 =head1 ADDITIONAL MANUALS
 
 =over
